@@ -45,7 +45,7 @@ def gen_url_regex(resource):
 def fix_request(request):
     methods = "PUT", "PATH"
 
-    if request.method in methods:
+    if request.method in methods and not getattr(request, request.method, None):
 
         if hasattr(request, '_post'):
             del(request._post)
